pub fn validate_patch_paths(content: &str) -> Result<(), PatchError>Expand description
Validate patch file path headers for traversal and symlink attacks.
pub fn validate_patch_paths(content: &str) -> Result<(), PatchError>Validate patch file path headers for traversal and symlink attacks.