Module triage

Module triage 

Triage status detection for GitHub issues.

This module provides utilities to check whether an issue has already been triaged, either through labels or Aptu-generated comments.

Structs

TriageStatus
Status of whether an issue has already been triaged

Constants

APTU_SIGNATURE
Signature string used to identify Aptu-generated triage comments

Functions

check_already_triaged
Check if an issue has already been triaged.
render_pr_review_comment_body
Formats an inline PR review comment body.
render_pr_review_markdown
Renders a concise PR review body for posting to GitHub.
render_release_notes_markdown
Render a ReleaseNotesResponse to markdown format.
render_triage_markdown
Renders triage response as markdown for posting to GitHub.