TriageStatus

Struct TriageStatus 

pub struct TriageStatus {
    pub has_type_label: bool,
    pub has_priority_label: bool,
    pub has_aptu_comment: bool,
    pub label_names: Vec<String>,
}
Status of whether an issue has already been triaged

Fields

has_type_label: bool

Whether the issue has a type label (bug, enhancement, etc.)

has_priority_label: bool

Whether the issue has a priority label (p0-p4, priority: high/medium/low)

has_aptu_comment: bool

Whether the issue has an Aptu-generated comment

label_names: Vec<String>

List of labels that indicate triage status

Implementations

Source

impl TriageStatus

pub fn new( has_type_label: bool, has_priority_label: bool, has_aptu_comment: bool, label_names: Vec<String>, ) -> Self

Create a new TriageStatus.

pub fn is_triaged(&self) -> bool

Check if the issue has been triaged (has both type and priority labels, or Aptu comment).